"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createWebpackAssets = createWebpackAssets;
exports.webpackMeasureFileSizesBeforeBuild = webpackMeasureFileSizesBeforeBuild;

var fs = _interopRequireWildcard(require("fs-extra"));

var _gzipSize = require("gzip-size");

var path = _interopRequireWildcard(require("path"));

var _recursiveReaddir = _interopRequireDefault(require("recursive-readdir"));

var _fileSizeReporter = require("./fileSizeReporter");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function removeFileNameHash(fileName) {
  return fileName.replace(/\\/g, '/').replace(/\/?(.*)(\.[0-9a-f]+)(\.chunk)?(\.js|\.css)/, (match, p1, p2, p3, p4) => p1 + p4);
}

function webpackMeasureFileSizesBeforeBuild(buildFolder) {
  return new Promise(resolve => {
    (0, _recursiveReaddir.default)(buildFolder, (err, fileNames) => {
      if (err) {
        resolve({});
      } else {
        resolve(fileNames.filter(_fileSizeReporter.canReadAsset).reduce((memo, fileName) => {
          let contents = fs.readFileSync(fileName);
          let key = removeFileNameHash(path.relative(buildFolder, fileName));
          memo[key] = (0, _gzipSize.sync)(contents);
          return memo;
        }, {}));
      }
    });
  });
}

function createWebpackAssets(paths, stats) {
  var _stats$assets;

  const readableAssets = (((_stats$assets = stats.assets) === null || _stats$assets === void 0 ? void 0 : _stats$assets.filter(asset => (0, _fileSizeReporter.canReadAsset)(asset.name))) || []).map(asset => asset.name);
  return readableAssets.map(name => {
    const fileContents = fs.readFileSync(path.join(paths.appBuild, name));
    const size = (0, _gzipSize.sync)(fileContents);
    return {
      folder: path.join(path.basename(paths.appBuild), path.dirname(name)),
      name: path.basename(name),
      normalizedName: removeFileNameHash(name),
      size: size
    };
  }).sort((a, b) => b.size - a.size);
}
//# sourceMappingURL=webpackFileSizeReporter.js.map