"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var path = _interopRequireWildcard(require("path"));

var _isCi = _interopRequireDefault(require("is-ci"));

var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));

var _resolveAsBin = require("./utils/resolveAsBin");

var _getModularRoot = _interopRequireDefault(require("./utils/getModularRoot"));

var _execAsync = _interopRequireDefault(require("./utils/execAsync"));

var _gitActions = require("./utils/gitActions");

var logger = _interopRequireWildcard(require("./utils/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

async function lint(options, regexes = []) {
  const {
    all = false,
    fix = false
  } = options;
  const modularRoot = (0, _getModularRoot.default)();
  const lintExtensions = ['.ts', '.tsx', '.js', '.jsx'];
  let targetedFiles = ['<rootDir>/**/src/**/*.{js,jsx,ts,tsx}'];

  if (!all && !_isCi.default && !regexes) {
    const diffedFiles = (0, _gitActions.getDiffedFiles)();

    if (diffedFiles.length === 0) {
      logger.log('No diffed files detected. Add the `--all` option to lint the entire codebase');
      return;
    }

    const targetExts = diffedFiles.filter(p => lintExtensions.includes(path.extname(p))).map(p => `<rootDir>/${p}`); // if none of the diffed files do not meet the extension criteria, do not lint
    // end the process early with a success

    if (!targetExts.length) {
      logger.debug('No diffed js,jsx,ts,tsx files found');
      return;
    }

    targetedFiles = targetExts;
  }

  const jestEslintConfig = {
    runner: require.resolve('modular-scripts/jest-runner-eslint'),
    displayName: 'lint',
    rootDir: modularRoot,
    testMatch: targetedFiles,
    testPathIgnorePatterns: ['/node_modules/', '/dist/']
  };
  const testArgs = [...regexes, '--config', `"${JSON.stringify(jestEslintConfig)}"`];
  const testBin = await (0, _resolveAsBin.resolveAsBin)('jest-cli');

  try {
    await (0, _execAsync.default)(testBin, testArgs, {
      cwd: modularRoot,
      log: false,
      // @ts-ignore
      env: {
        MODULAR_ROOT: modularRoot,
        MODULAR_LINT_FIX: String(fix)
      }
    });
  } catch (err) {
    logger.debug(err.message); // ✕ Modular lint did not pass

    throw new Error('\u2715 Modular lint did not pass');
  }
}

var _default = (0, _actionPreflightCheck.default)(lint);

exports.default = _default;
//# sourceMappingURL=lint.js.map