"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.addFixturePackage = addFixturePackage;
exports.cleanup = cleanup;
exports.modular = modular;

var _rimraf2 = _interopRequireDefault(require("rimraf"));

var _execa = _interopRequireDefault(require("execa"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _util = require("util");

var _getModularRoot = _interopRequireDefault(require("../utils/getModularRoot"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const rimraf = (0, _util.promisify)(_rimraf2.default);
const modularRoot = (0, _getModularRoot.default)();

function modular(str, opts = {}) {
  return (0, _execa.default)('yarnpkg', ['modular', ...str.split(' ')], {
    cwd: modularRoot,
    cleanup: true,
    ...opts
  });
}

async function cleanup(packageNames) {
  const packagesPath = _path.default.join(modularRoot, 'packages');

  const distPath = _path.default.join(modularRoot, 'dist');

  for (const packageName of packageNames) {
    await rimraf(_path.default.join(packagesPath, packageName));
    await rimraf(_path.default.join(distPath, packageName));
  } // run yarn so yarn.lock gets reset


  await (0, _execa.default)('yarnpkg', ['--silent'], {
    cwd: modularRoot
  });
}

async function addFixturePackage(name, options = {
  copy: true
}) {
  const packageSrcDir = _path.default.join(modularRoot, 'packages', name, 'src');

  await modular(`add ${name} --unstable-type package --unstable-name ${name}`, {
    stdio: 'inherit'
  });
  await _fsExtra.default.emptyDir(packageSrcDir);

  if (options.copy) {
    await _fsExtra.default.copy(_path.default.join(__dirname, '..', '__tests__', '__fixtures__', 'packages', name), packageSrcDir);
  }
}
//# sourceMappingURL=utils.js.map