"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPackageDependencies = getPackageDependencies;

var path = _interopRequireWildcard(require("path"));

var fs = _interopRequireWildcard(require("fs-extra"));

var _tsMorph = require("ts-morph");

var _getModularRoot = _interopRequireDefault(require("./getModularRoot"));

var _getLocation = _interopRequireDefault(require("./getLocation"));

var _getWorkspaceInfo = _interopRequireDefault(require("./getWorkspaceInfo"));

var logger = _interopRequireWildcard(require("./logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const npmPackageMatcher = /^(@[a-z0-9-~][a-z0-9-._~]*\/)?[a-z0-9-~][a-z0-9-._~]*/;
/* Get dependencies from import / require declarations, since they could be hoisted to the root workspace. Exclude test files. */

function getDependenciesFromSource(workspaceLocation) {
  const project = new _tsMorph.Project();
  project.addSourceFilesAtPaths(path.join(workspaceLocation, 'src/**/!(*.test){.d.ts,.ts,.js,.jsx,.tsx}'));
  const dependencySet = new Set(project.getSourceFiles().flatMap(sourceFile => sourceFile.getImportDeclarations().map(declaration => {
    var _npmPackageMatcher$ex;

    return (_npmPackageMatcher$ex = npmPackageMatcher.exec(declaration.getModuleSpecifierValue())) === null || _npmPackageMatcher$ex === void 0 ? void 0 : _npmPackageMatcher$ex[0];
  })).filter(Boolean));
  return Array.from(dependencySet);
}

async function getPackageDependencies(target) {
  /* This function is based on the assumption that nested package are not supported, so dependencies can be either declared in the
   * target's package.json or hoisted up to the workspace root.
   */
  const targetLocation = await (0, _getLocation.default)(target);
  const workspaceInfo = (0, _getWorkspaceInfo.default)();
  const rootManifest = fs.readJSONSync(path.join((0, _getModularRoot.default)(), 'package.json'));
  const targetManifest = fs.readJSONSync(path.join(targetLocation, 'package.json'));
  const deps = Object.assign(Object.create(null), targetManifest.devDependencies, rootManifest.devDependencies, targetManifest.dependencies, rootManifest.dependencies);
  /* Get regular dependencies from package.json (regular) or root package.json (hoisted)
   * Exclude workspace dependencies. Error if a dependency is imported in the source code
   * but not specified in any of the package.jsons
   */

  const manifest = getDependenciesFromSource(targetLocation).filter(depName => !(depName in workspaceInfo)).reduce((manifest, depName) => {
    const depVersion = deps[depName];

    if (!depVersion) {
      logger.error(`Package ${depName} imported in ${target} source but not found in package dependencies or hoisted dependencies - this will prevent you from successfully build, start or move packages in the next release of modular`);
    }

    manifest[depName] = depVersion;
    return manifest;
  }, {});
  return manifest;
}
//# sourceMappingURL=getPackageDependencies.js.map